Module flowstdlib::data::count[][src]

A module that counts data passed thru it

Structs

Count

Takes a value on it’s input and sends the same value on it’s output and adds one to the count received on ‘count’ input and outputs new count on ‘count’ output