Struct flowstdlib::data::count::Count

source ·
pub struct Count;
Count (//flowstdlib/data/count)

Takes a value on it’s input and sends the same value on it’s output and adds one to the count received on ‘count’ input and outputs new count on ‘count’ output

Include using

[[process]]
source = "lib://flowstdlib/data/count"

Definition

function = "count"
source = "count.rs"
docs = "count.md"
type = "rust"

[[input]]
name = "data" # the value to count and pass on

[[input]]
name = "count" # - the count before this data item

[[output]]
name = "data" # - the value passed on

[[output]]
name = "count" # - the incremented count of values passed thru