[][src]Crate flowstdlib

flowstdlib is a standard library of functions for flow programs to use. It can be compiled and linked natively to a runtime, or each function can be compiled to WebAssembly and loaded from file by the runtime.