Struct flowstdlib::math::compare::Compare
source · pub struct Compare;Expand description
Compare (//flowstdlib/math/compare)
Compare two input values and output different boolean values depending on if the comparison is equal, greater than, greater than or equal, less than or less than or equal.
Include using
[[process]]
source = "lib://flowstdlib/math/compare"
Definition
function = "compare"
source = "compare.rs"
docs = "compare.md"
type = "rust"
[[input]]
name = "left" # - left hand input
type = "number"
[[input]]
name = "right" # - right hand input
type = "number"
[[output]]
name = "equal" # - `equal` - outputs true if the two values are equal
type = "boolean"
[[output]]
name = "ne" # - `ne` - outputs true if the two values are not equal
type = "boolean"
[[output]]
name = "lt" # - `lt` - outputs true if the left hand value is less than the right hand value
type = "boolean"
[[output]]
name = "lte" # - `lte` - outputs true if the left hand value is less than or equal to the right hand value
type = "boolean"
[[output]]
name = "gt" # - `gt` - outputs true if the left hand value is greater than the right hand value
type = "boolean"
[[output]]
name = "gte" # - `gte` - outputs true if the left hand value is greater than or equal to the right hand value
type = "boolean"