[][src]Struct flowstdlib::math::compare::Compare

pub struct Compare;

Compare two input values and output different boolean values depending on if the comparison is equal, greater than, greater than or equal, less than or less than or equal.